@@ -23,6 +23,8 @@ class DataTable(Snippet):
     def __init__(
         self,
         headers: List[str],
+        page_length: Optional[int] = 10,
+        paging: Optional[bool] = True,
         classes: ITableClasses = ITableClasses(),
     ) -> None:
         """Create table."""
@@ -46,12 +48,16 @@ class DataTable(Snippet):
                 """
                 new simpleDatatables.DataTable('#{{ id }}_inner', {
                     searchable: true,
+                    pageLength: {{ page_length }},
+                    paging: {{ paging }},
                     columns: [
                         { select: 2, sort: 'desc' },
                     ]
                 })
                 """,
-                id=self.uid))
+                id=self.uid,
+                paging=str(paging).lower(),
+                page_length=page_length))
 
     def add_row(
         self,
